==> qmmp_0.2.3.orig.tar.gz: qmmp-0.2.3/src/plugins/General/statusicon/translations/statusicon_plugin_zh_TW.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS><TS version="1.1" language="zh_TW">
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="13"/>
        <source>Status Icon Plugin Settings</source>
        <translation>狀態圖像插件設定</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="19"/>
        <source>Show message</source>
        <translation>察看訊息</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="26"/>
        <source>Show tooltip</source>
        <translation>察看工具輔助說明</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="33"/>
        <source>Message delay, ms:</source>
        <translation>訊息延時(ms)：</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="89"/>
        <source>OK</source>
        <translation>確定</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="96"/>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
</context>
<context>
    <name>StatusIcon</name>
    <message>
        <location filename="../statusicon.cpp" line="39"/>
        <source>Play</source>
        <translation>播放</translation>
    </message>
    <message>
        <location filename="../statusicon.cpp" line="40"/>
        <source>Pause</source>
        <translation>暫停</translation>
    </message>
    <message>
        <location filename="../statusicon.cpp" line="41"/>
        <source>Stop</source>
        <translation>停止</translation>
    </message>
    <message>
        <location filename="../statusicon.cpp" line="42"/>
        <source>Next</source>
        <translation>下一曲</translation>
    </message>
    <message>
        <location filename="../statusicon.cpp" line="43"/>
        <source>Previous</source>
        <translation>上一曲</translation>
    </message>
    <message>
        <location filename="../statusicon.cpp" line="45"/>
        <source>Exit</source>
        <translation>結束</translation>
    </message>
    <message>
        <location filename="../statusicon.cpp" line="96"/>
        <source>Now Playing</source>
        <translation>正在播放</translation>
    </message>
</context>
<context>
    <name>StatusIconFactory</name>
    <message>
        <location filename="../statusiconfactory.cpp" line="30"/>
        <source>Status Icon Plugin</source>
        <translation>狀態圖像插件</translation>
    </message>
    <message>
        <location filename="../statusiconfactory.cpp" line="50"/>
        <source>Qmmp Status Icon Plugin</source>
        <translation>Qmmp 狀態圖像插件</translation>
    </message>
    <message>
        <location filename="../statusiconfactory.cpp" line="51"/>
        <source>Writen by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>作者：Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
    <message>
        <location filename="../statusiconfactory.cpp" line="49"/>
        <source>About Status Icon Plugin</source>
        <translation>關於狀態圖像插件</translation>
    </message>
</context>
</TS>

==> qmmp_0.3.1.orig.tar.gz: qmmp-0.3.1/src/plugins/General/statusicon/translations/statusicon_plugin_zh_TW.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="zh_TW">
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>Status Icon Plugin Settings</source>
        <translation>狀態圖像插件設定</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="20"/>
        <source>Show message</source>
        <translation>察看訊息</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="27"/>
        <source>Show tooltip</source>
        <translation>察看工具輔助說明</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="34"/>
        <source>Message delay, ms:</source>
        <translation>訊息延時(ms)：</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="86"/>
        <source>Use standard icons</source>
        <translation>使用標准圖標</translation>
    </message>
</context>
<context>
    <name>StatusIcon</name>
    <message>
        <location filename="../statusicon.cpp" line="46"/>
        <source>Play</source>
        <translation>播放</translation>
    </message>
    <message>
        <location filename="../statusicon.cpp" line="47"/>
        <source>Pause</source>
        <translation>暫停</translation>
    </message>
    <message>
        <location filename="../statusicon.cpp" line="48"/>
        <source>Stop</source>
        <translation>停止</translation>
    </message>
    <message>
        <location filename="../statusicon.cpp" line="49"/>
        <source>Next</source>
        <translation>下一曲</translation>
    </message>
    <message>
        <location filename="../statusicon.cpp" line="50"/>
        <source>Previous</source>
        <translation>上一曲</translation>
    </message>
    <message>
        <location filename="../statusicon.cpp" line="52"/>
        <source>Exit</source>
        <translation>結束</translation>
    </message>
    <message>
        <location filename="../statusicon.cpp" line="127"/>
        <source>Now Playing</source>
        <translation>正在播放</translation>
    </message>
</context>
<context>
    <name>StatusIconFactory</name>
    <message>
        <location filename="../statusiconfactory.cpp" line="30"/>
        <source>Status Icon Plugin</source>
        <translation>狀態圖像插件</translation>
    </message>
    <message>
        <location filename="../statusiconfactory.cpp" line="51"/>
        <source>Qmmp Status Icon Plugin</source>
        <translation>Qmmp 狀態圖像插件</translation>
    </message>
    <message>
        <location filename="../statusiconfactory.cpp" line="52"/>
        <source>Writen by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>作者：Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
    <message>
        <location filename="../statusiconfactory.cpp" line="50"/>
        <source>About Status Icon Plugin</source>
        <translation>關於狀態圖像插件</translation>
    </message>
</context>
</TS>
